@@ -1,6 +1,6 @@
 /* Test of concatenation of two arbitrary file names.
 
-   Copyright (C) 1996-2007, 2009-2017 Free Software Foundation, Inc.
+   Copyright (C) 1996-2007, 2009-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Written by Jim Meyering.  */
 
@@ -22,6 +22,7 @@
 #include "filenamecat.h"
 
 #include <stdbool.h>
+#include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -38,11 +39,11 @@ main (int argc _GL_UNUSED, char *argv[])
       {"a", "/b",  "a/b"},
 
       {"/", "b",  "/b"},
-      {"/", "/b", "/b"},
-      {"/", "/",  "/"},
+      {"/", "/b", "/./b"}, /* This result could be shorter.  */
+      {"/", "/",  "/./"},  /* This result could be shorter.  */
       {"a", "/",  "a/"},   /* this might deserve a diagnostic */
       {"/a", "/", "/a/"},  /* this might deserve a diagnostic */
-      {"a", "//b",  "a/b"},
+      {"a", "//b",  "a//b"},
       {"", "a", "a"},  /* this might deserve a diagnostic */
     };
   unsigned int i;
@@ -53,11 +54,31 @@ main (int argc _GL_UNUSED, char *argv[])
       char *base_in_result;
       char const *const *t = tests[i];
       char *res = file_name_concat (t[0], t[1], &base_in_result);
+      ptrdiff_t prefixlen = base_in_result - res;
+      size_t t0len = strlen (t[0]);
+      size_t reslen = strlen (res);
       if (strcmp (res, t[2]) != 0)
         {
           fprintf (stderr, "test #%u: got %s, expected %s\n", i, res, t[2]);
           fail = true;
         }
+      if (strcmp (t[1], base_in_result) != 0)
+        {
+          fprintf (stderr, "test #%u: base %s != base_in_result %s\n",
+                   i, t[1], base_in_result);
+          fail = true;
+        }
+      if (! (0 <= prefixlen && prefixlen <= reslen))
+        {
+          fprintf (stderr, "test #%u: base_in_result is not in result\n", i);
+          fail = true;
+        }
+      if (reslen < t0len || memcmp (res, t[0], t0len) != 0)
+        {
+          fprintf (stderr, "test #%u: %s is not a prefix of %s\n",
+                   i, t[0], res);
+          fail = true;
+        }
     }
   exit (fail ? EXIT_FAILURE : EXIT_SUCCESS);
 }
