@@ -1,5 +1,5 @@
 /* Test regular expressions
-   Copyright 1996-2001, 2003-2017 Free Software Foundation, Inc.
+   Copyright 1996-2001, 2003-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
@@ -48,7 +48,7 @@ main (void)
   if (setlocale (LC_ALL, "en_US.UTF-8"))
     {
       {
-        /* http://sourceware.org/ml/libc-hacker/2006-09/msg00008.html
+        /* https://sourceware.org/ml/libc-hacker/2006-09/msg00008.html
            This test needs valgrind to catch the bug on Debian
            GNU/Linux 3.1 x86, but it might catch the bug better
            on other platforms and it shouldn't hurt to try the
@@ -83,7 +83,7 @@ main (void)
         {
           /* This test is from glibc bug 15078.
              The test case is from Andreas Schwab in
-             <http://www.sourceware.org/ml/libc-alpha/2013-01/msg00967.html>.
+             <https://sourceware.org/ml/libc-alpha/2013-01/msg00967.html>.
           */
           static char const pat[] = "[^x]x";
           static char const data[] =
@@ -220,7 +220,7 @@ main (void)
     }
 
   /* Catch a bug reported by Vin Shelton in
-     http://lists.gnu.org/archive/html/bug-coreutils/2007-06/msg00089.html
+     https://lists.gnu.org/r/bug-coreutils/2007-06/msg00089.html
      */
   re_set_syntax (RE_SYNTAX_POSIX_BASIC
                  & ~RE_CONTEXT_INVALID_DUP
@@ -237,6 +237,17 @@ main (void)
   if (! REG_STARTEND)
     result |= 64;
 
+  /* Matching with the compiled form of this regexp would provoke
+     an assertion failure prior to glibc-2.28:
+       regexec.c:1375: pop_fail_stack: Assertion 'num >= 0' failed
+     With glibc-2.28, compilation fails and reports the invalid
+     back reference.  */
+  re_set_syntax (RE_SYNTAX_POSIX_EGREP);
+  memset (&regex, 0, sizeof regex);
+  s = re_compile_pattern ("0|()0|\\1|0", 10, &regex);
+  if (!s || strcmp (s, "Invalid back reference"))
+    result |= 64;
+
 #if 0
   /* It would be nice to reject hosts whose regoff_t values are too
      narrow (including glibc on hosts with 64-bit ptrdiff_t and
