@@ -1,7 +1,7 @@
-/* diff - compare files line by line
+/* GNU diff - compare files line by line
 
    Copyright (C) 1988-1989, 1992-1994, 1996, 1998, 2001-2002, 2004, 2006-2007,
-   2009-2013, 2015-2017 Free Software Foundation, Inc.
+   2009-2013, 2015-2018 Free Software Foundation, Inc.
 
    This file is part of GNU DIFF.
 
@@ -1009,6 +1009,9 @@ Mandatory arguments to long options are mandatory for short options too.\n\
 	  while ((nl = strchr (msg, '\n')))
 	    {
 	      int msglen = nl + 1 - msg;
+	      /* This assertion is solely to avoid a warning from
+		 gcc's -Wformat-overflow=.  */
+	      assert (msglen < 4096);
 	      printf ("  %.*s", msglen, msg);
 	      msg = nl + 1;
 	    }
